pub fn op_append_items(body: &str, items: &[PendingItem]) -> StringExpand description
Append existing tracked items after the current item list, preserving order.
pub fn op_append_items(body: &str, items: &[PendingItem]) -> StringAppend existing tracked items after the current item list, preserving order.