pub fn op_insert_item_first(body: &str, item: PendingItem) -> StringExpand description
Insert an existing tracked item at the first item slot of a component body.
pub fn op_insert_item_first(body: &str, item: PendingItem) -> StringInsert an existing tracked item at the first item slot of a component body.