pub fn render_annotation(predicate: &GatePredicate) -> StringExpand description
Render the predicate to its canonical inline annotation. Empty fields are omitted. Returns an empty string when the predicate has no fields at all.
pub fn render_annotation(predicate: &GatePredicate) -> StringRender the predicate to its canonical inline annotation. Empty fields are omitted. Returns an empty string when the predicate has no fields at all.